bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaISO.__init__
====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGammaISO.__init__